==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pt_br/lesson.php <==
<?PHP // $Id$ 
      // lesson.php - created with Moodle 1.4.2 (2004083120)


$string['actionaftercorrectanswer'] = 'Ao depois da resposta correta';
$string['addabranchtable'] = 'Inserir pgina com painel de navegao';
$string['addanendofbranch'] = 'Inserir fim de seo';
$string['addaquestionpage'] = 'Inserir pgina com questes';
$string['addcluster'] = 'Inserir cluster';
$string['addendofcluster'] = 'Inserir fim de cluster';
$string['answer'] = 'Resposta';
$string['answersfornumerical'] = 'As respostas para questes numricas devem ser pares de valores mximos e mnimos';
$string['arrangebuttonshorizontally'] = 'Ordenar os pulsantes das sees horizontalmente em modalidade Slide Show?';
$string['attempt'] = 'Tentativa: $a';
$string['attempts'] = 'Tentativas';
$string['available'] = 'Disponvel a partir de';
$string['backtreeview'] = 'Retornar  visualizao por sees';
$string['branchtable'] = 'Painel de Navegao';
$string['cancel'] = 'Cancelar';
$string['canretake'] = '$a pode tentar novamente';
$string['casesensitive'] = 'Considera diferena entre maisculas e minsculas';
$string['checkbranchtable'] = 'Testar painel de navegao';
$string['checknavigation'] = 'Testar navegao';
$string['checkquestion'] = 'Testar questo';
$string['clicktopost'] = 'Clique aqui para adicionar a sua nota  lista dos melhores resultados';
$string['clusterjump'] = 'Questo no vista em um cluster';
$string['clustertitle'] = 'Cluster';
$string['comments'] = 'Seus comentrios';
$string['confirmdeletionofthispage'] = 'Confirma cancelamento desta pgina';
$string['congratulations'] = 'Voc chegou ao fim desta lio';
$string['continue'] = 'Continuar';
$string['correctanswerjump'] = 'Destinao da resposta correta';
$string['correctanswerscore'] = 'Pontuao da resposta correta';
$string['correctresponse'] = 'Resposta correta';
$string['customscoring'] = 'Pontuao padro';
$string['deadline'] = 'Prazo final';
$string['deleteattempts'] = 'Cancelar tentativas do estudante nesta lio (user id)';
$string['deleting'] = 'Cancelando';
$string['deletingpage'] = 'Cancelando pgina: $a';
$string['description'] = 'Texto do link';
$string['displayhighscores'] = 'Mostrar pontuaoes altas';
$string['displayinleftmenu'] = 'Mostrar no men  esquerda?';
$string['displayleftmenu'] = 'Mostrar men  esquerda';
$string['displayofgrade'] = 'Visualizao das notas (apenas para estudantes)';
$string['displayreview'] = 'Mostrar boto reviso';
$string['displayscorewithessays'] = 'Voc recebeu $a->score de um total de $a->tempmaxgrade nas questes avaliadas automaticamente.<br> A(s) sua(s) $a->essayquestions pergunta(s) dissertativa(s) sero avaliadas depois.<br><br>A sua nota parcial  $a->score de um total de $a->grade';
$string['displayscorewithoutessays'] = 'A sua pontuao  $a->score (de $a->grade).';
$string['editlessonsettings'] = 'Editar as configuraes desta lio';
$string['editpagecontent'] = 'Editar o contedo desta pgina';
$string['email'] = 'Email';
$string['emailallgradedessays'] = 'Enviar email de <br> todas as dissertaes avaliadas';
$string['emailgradedessays'] = 'Enviar email das dissertaes avaliadas';
$string['emailsuccess'] = 'Envio de email bem sucedido';
$string['endofbranch'] = 'Fim da seo';
$string['endofclustertitle'] = 'Fim do cluster';
$string['endoflesson'] = 'Fim da lio';
$string['entername'] = 'Inserir um apelido para a lista de pontuaes altas';
$string['enterpassword'] = 'Inserir a senha, por favor';
$string['eolstudentoutoftime'] = 'Ateno: O tempo para terminar esta lio acabou. Se a sua litma resposta foi enviada quando o tempo de durao j tinha sido superado, ela no ser considerada.';
$string['eolstudentoutoftimenoanswers'] = 'Voc no respondeu nenhuma questo. A nota atribuda foi igual a 0 .';
$string['essay'] = 'Dissertao';
$string['essays'] = 'Dissertaes';
$string['essayscore'] = 'Nota da dissertao';
$string['fileformat'] = 'Formato do documento';
$string['firstanswershould'] = 'A primeira resposta deve ter como destinao a pgina  correta';
$string['firstwrong'] = 'Infelizmente esta resposta no  correta e portanto no aumentar a sua pontuao. Voc gostaria de continuar tentando para conhecer a resposta certa (mas sem direito  reviso da pontuao)?';
$string['gradeessay'] = 'Avaliar dissertaes';
$string['gradeis'] = 'Resultado: $a';
$string['handlingofretakes'] = 'Clculo do resultado das tentativas';
$string['here'] = 'aqui';
$string['importquestions'] = 'Importar questes';
$string['jump'] = 'Destinao';
$string['leftduringtimed'] = 'Voc interrompeu uma lio com tempo de durao definido.<br>Por favor clique em Continuar para recomear a lio.';
$string['leftduringtimednoretake'] = 'Voc interrompeu uma lio com tempo de durao definido.<br>No ser possvel continuar ou recomear.';
$string['lessonclosed'] = 'Esta lio foi fechada em $a.';
$string['lessondefault'] = 'Usar as configuraes desta lio como padro';
$string['lessonmenu'] = 'Menu da lio';
$string['lessonopen'] = 'Esta lio ser acessvel a partir de $a.';
$string['loginfail'] = 'Erro de login, por favor tente novamente';
$string['mainmenu'] = 'Menu principal';
$string['matchesanswer'] = 'Corresponde  resposta';
$string['maxhighscores'] = 'Nmero de pontuaes altas visualizado';
$string['maximumnumberofanswersbranches'] = 'Nmero mximo de respostas/sees';
$string['maximumnumberofattempts'] = 'Nmero mximo de tentativas';
$string['maxtime'] = 'Limite temporal (minutos)';
$string['maxtimewarning'] = 'Voc tem $a minuto(s) para terminar esta lio.';
$string['minimumnumberofquestions'] = 'Nmero mnimo  de questes';
$string['modulename'] = 'Lio';
$string['modulenameplural'] = 'Lies';
$string['movepagehere'] = 'Mover pgina para c';
$string['moving'] = 'Movendo pgina: $a';
$string['movingtonextpage'] = 'Movendo para a prxima pgina';
$string['multianswer'] = 'Multianswer';
$string['multipleanswer'] = 'Resposta mltipla';
$string['nameapproved'] = 'Nome aprovado';
$string['namereject'] = 'Sinto muito, o seu nome no foi aceito pelo filtro.<br>Por favor use um outro nome.';
$string['nextpage'] = 'Prxima pgina';
$string['noanswer'] = 'No foi dada nenhuma resposta';
$string['noattemptrecordsfound'] = 'No foram encontrados registros de tentativas para esta lio: no foi definido nenhum resultado';
$string['nohighscores'] = 'Nenhuma pontuao alta';
$string['noretake'] = 'No  permitido refazer esta lio';
$string['normal'] = 'Normal - seguir percurso da lio';
$string['notdefined'] = 'No definido';
$string['nothighscore'] = 'O seu resultado no est includo entre os melhores $a da lista.';
$string['notitle'] = 'Nenhum ttulo';
$string['numberofcorrectanswers'] = 'Nmero de respostas corretas: $a';
$string['numberofcorrectmatches'] = 'Nmero de associaes corretas';
$string['numberofpagestoshow'] = 'Nmero  de pginas (fichas) a serem mostradas ';
$string['numberofpagesviewed'] = 'Nmero de pginas vistas: $a';
$string['ongoing'] = 'Visualizar pontuao corrente';
$string['ongoingcustom'] = 'Esta lio corresponde a $a->grade pontos. Voc recebeu $a->score ponto(s) de um total de $a->currenthigh pontos at agora.';
$string['ongoingnormal'] = 'Voc respondeu corretamente $a->correct questes de um total de $a->viewed .';
$string['ordered'] = 'Ordenada';
$string['outof'] = 'de $a';
$string['outoftime'] = 'Sem tempo';
$string['page'] = 'Pgina: $a';
$string['pagecontents'] = 'Contedo da pgina';
$string['pages'] = 'Pginas';
$string['pagetitle'] = 'Ttulo da pgina';
$string['password'] = 'Senha';
$string['passwordprotectedlesson'] = '$a  uma atividade protegida por uma senha';
$string['pleasecheckoneanswer'] = 'Salvar a resposta selecionada';
$string['pleasecheckoneormoreanswers'] = 'Salvar as respostas selecionadas';
$string['pleaseenteryouranswerinthebox'] = 'Salvar a resposta escrita no box ';
$string['pleasematchtheabovepairs'] = 'Salvar os pares associados acima';
$string['postsuccess'] = 'Envio bem sucedido';
$string['practice'] = 'Exerccio';
$string['previouspage'] = 'Pgina anterior';
$string['question'] = 'Questo';
$string['questionoption'] = 'Modalidade opcional';
$string['questiontype'] = 'Tipo de questo';
$string['randombranch'] = 'Pgina de seo aleatria';
$string['randompageinbranch'] = 'Questo aleatria de uma seo';
$string['rank'] = 'Classificao';
$string['reached'] = 'alcanado';
$string['redisplaypage'] = 'Mostrar pgina de novo';
$string['response'] = 'Comentrio';
$string['returnmainmenu'] = 'Voltar ao men';
$string['returntocourse'] = 'Voltar ao curso';
$string['reviewquestionback'] = 'Sim, eu gostaria de tentar novamente';
$string['reviewquestioncontinue'] = 'No, quero continuar com a prxima questo';
$string['sanitycheckfailed'] = 'O controle dos dados falhou: Esta tentativa foi cancelada';
$string['savepage'] = 'Salvar pgina';
$string['score'] = 'Pontuao';
$string['scores'] = 'Pontuaes';
$string['secondpluswrong'] = 'No  exato. Voc quer tentar novamente?';
$string['showanunansweredpage'] = 'Mostrar uma pgina que ainda no foi respondida';
$string['showanunseenpage'] = 'Mostrar uma pgina que ainda no foi visitada';
$string['singleanswer'] = 'Resposta nica';
$string['slideshow'] = 'Slide Show';
$string['slideshowbgcolor'] = 'Cr do fundo da pgina do Slide Show ';
$string['slideshowheight'] = 'Altura do Slide Show ';
$string['slideshowwidth'] = 'Largura do Slide Show ';
$string['startlesson'] = 'Iniciar Lio';
$string['studentoneminwarning'] = 'Ateno: Voc tem menos de 1 minuto para acabar a lio.';
$string['studentoutoftime'] = 'Ateno: acabou o tempo de durao desta lio. A sua ltima resposta no ser considerada porque foi enviada depois do termo. Por favor clique o boto Continuar para encerrar esta lio';
$string['studentresponse'] = 'resposta de {$a}';
$string['submitname'] = 'Enviar nome';
$string['teacherjumpwarning'] = 'Uma destinao $a->cluster ou uma destinao $a->unseen est sendo usado nesta lio. A destinao Prxima Pgina substituir a anterior. Faa o login como estudante para testar estas destinaes.';
$string['teacherongoingwarning'] = 'Para testar a pontuao corrente  necessrio fazer o login como estudante.';
$string['teachertimerwarning'] = 'Para testar o timer  necessrio fazer o login como estudante.';
$string['thatsthecorrectanswer'] = 'Esta  a resposta correta';
$string['thatsthewronganswer'] = 'Esta  a resposta errada';
$string['thefollowingpagesjumptothispage'] = 'As seguintes pginas tem como destinao esta pgina';
$string['thispage'] = 'Esta pgina';
$string['timed'] = 'Tempo determinado';
$string['topscorestitle'] = '$a->maxhighscores melhores pontuaes da lio $a->name .';
$string['treeview'] = 'Vista em forma de rvore';
$string['unseenpageinbranch'] = 'Questao no vista de uma seo';
$string['updatefailed'] = 'Erro na atualizao';
$string['updatesuccess'] = 'Atualizao bem sucedida';
$string['useeditor'] = 'Usar editor';
$string['usemaximum'] = 'Usar melhor resultado entre as tentativas';
$string['usemean'] = 'Usar mdia das tentativas';
$string['usepassword'] = 'Lio protegida por senha';
$string['viewallpages'] = 'Ver todas as pginas';
$string['viewgrades'] = 'Ver notas';
$string['viewhighscores'] = 'Ver lista dos melhores resultados';
$string['waitpostscore'] = 'Por favor espere enquanto a pontuao est sendo enviada...';
$string['welldone'] = 'Muito bem!';
$string['whatdofirst'] = 'O que voc gostaria de fazer primeiro?';
$string['wronganswerjump'] = 'Destinao da resposta errada';
$string['wronganswerscore'] = 'Pontuao da resposta errada';
$string['wrongresponse'] = 'Resposta errada';
$string['youhaveseen'] = 'Voc j visitou algumas pginas desta lio.<br />Voc quer iniciar a partir da ltima pgina visitada?';
$string['youmadehighscore'] = 'O seu resultado est incluido entre os melhores $a .';
$string['youranswer'] = 'A sua resposta';
$string['yourcurrentgradeis'] = 'A sua avaliao atual  $a';
$string['youshouldview'] = 'Voc deve visitar pelo menos: $a';

?>

==> moodle_1.5.3+20060108.orig.tar.gz: moodle/lang/pt_br/lesson.php <==
<?PHP // $Id$ 
      // lesson.php - created with Moodle 1.5 + (2005060201)


$string['accesscontrol'] = 'Controle de acesso';
$string['actionaftercorrectanswer'] = 'Ao depois da resposta correta';
$string['addabranchtable'] = 'Inserir pgina com painel de navegao';
$string['addanendofbranch'] = 'Inserir fim de seo';
$string['addaquestionpage'] = 'Inserir pgina com questes';
$string['addcluster'] = 'Inserir Grupamento';
$string['addedabranchtable'] = 'Adicionado Painel de Navegao';
$string['addedanendofbranch'] = 'Adicionado  Fim da seo';
$string['addedaquestionpage'] = 'Adicionada Pgina de Questes';
$string['addedcluster'] = 'Adicionado Grupamento';
$string['addedendofcluster'] = 'Adiconado Fim de Grupamento';
$string['addendofcluster'] = 'Inserir Fim de Grupamento';
$string['and'] = 'E';
$string['answer'] = 'Resposta';
$string['answeredcorrectly'] = 'respondidas corretamente.';
$string['answersfornumerical'] = 'As respostas para questes numricas devem ser pares de valores mximos e mnimos';
$string['arrangebuttonshorizontally'] = 'Ordenar os botes das sees horizontalmente na modalidade Apresentao de Slides?';
$string['attempt'] = 'Tentativa: $a';
$string['attempts'] = 'Tentativas';
$string['available'] = 'Disponvel a partir de';
$string['averagescore'] = 'Pontuao mdia';
$string['averagetime'] = 'Tempo mdio';
$string['backtreeview'] = 'Retornar  visualizao por sees';
$string['branchtable'] = 'Painel de Navegao';
$string['cancel'] = 'Cancelar';
$string['canretake'] = '$a pode tentar novamente';
$string['casesensitive'] = 'Considera diferena entre maisculas e minsculas';
$string['checkbranchtable'] = 'Testar painel de navegao';
$string['checkedthisone'] = 'selecionado este.';
$string['checknavigation'] = 'Testar navegao';
$string['checkquestion'] = 'Testar questo';
$string['classstats'] = 'Estatsticas da classe';
$string['clicktopost'] = 'Clique aqui para adicionar a sua nota  lista dos melhores resultados';
$string['clusterjump'] = 'Questo no vista em um grupamento';
$string['clustertitle'] = 'Grupamento';
$string['comments'] = 'Seus comentrios';
$string['commentswithname'] = 'comentrios de $a->firstname {$a->lastname}';
$string['completed'] = 'Completado';
$string['completederror'] = 'Completar a lio';
$string['completethefollowingconditions'] = 'Voc deve atingir os seguintes objetivos na lio <b>$a</b> antes de prosseguir.';
$string['conditionsfordependency'] = 'Condies de dependncia';
$string['confirmdeletionofthispage'] = 'Confirma cancelamento desta pgina';
$string['congratulations'] = 'Voc chegou ao fim desta lio';
$string['continue'] = 'Continuar';
$string['continuetoanswer'] = 'Continuar a mudar as respostas.';
$string['correctanswerjump'] = 'Destinao da resposta correta';
$string['correctanswerscore'] = 'Pontuao da resposta correta';
$string['correctresponse'] = 'Resposta correta';
$string['customscoring'] = 'Pontuao personalizada';
$string['deadline'] = 'Prazo final';
$string['defaultessayresponse'] = 'O seu trabalho vai ser avaliado pelo docente do curso.';
$string['deleteattempts'] = 'Cancelar tentativas do estudante nesta lio (user id)';
$string['deletedpage'] = 'Pgina cancelada';
$string['deleting'] = 'Cancelando';
$string['deletingpage'] = 'Cancelando pgina: $a';
$string['dependencyon'] = 'Dependente de';
$string['description'] = 'Texto do link';
$string['detailedstats'] = 'Estatsticas detalhadas';
$string['didnotanswerquestion'] = 'No respondeu esta questo';
$string['didnotreceivecredit'] = 'No recebeu nenhum crdito';
$string['displayhighscores'] = 'Mostrar pontuaes altas';
$string['displayinleftmenu'] = 'Mostrar no men  esquerda?';
$string['displayleftmenu'] = 'Mostrar men  esquerda';
$string['displayofgrade'] = 'Visualizao das notas (apenas para estudantes)';
$string['displayreview'] = 'Mostrar boto Reviso';
$string['displayscorewithessays'] = 'Voc recebeu $a->score de um total de $a->tempmaxgrade nas questes avaliadas automaticamente.<br /> A(s) sua(s) $a->essayquestions pergunta(s) dissertativa(s) sero avaliadas depois.<br /><br />A sua nota parcial  $a->score de um total de $a->grade';
$string['displayscorewithoutessays'] = 'A sua pontuao  $a->score (de $a->grade).';
$string['editlessonsettings'] = 'Editar as configuraes desta lio';
$string['editpagecontent'] = 'Editar o contedo desta pgina';
$string['email'] = 'Email';
$string['emailallgradedessays'] = 'Enviar email de <br /> todas as dissertaes avaliadas';
$string['emailgradedessays'] = 'Enviar email das dissertaes avaliadas';
$string['emailsuccess'] = 'Envio de email bem sucedido';
$string['endofbranch'] = 'Fim da seo';
$string['endofclustertitle'] = 'Fim do grupamento';
$string['endoflesson'] = 'Fim da lio';
$string['enteredthis'] = 'inserido este.';
$string['entername'] = 'Inserir um apelido para a lista de pontuaes altas';
$string['enterpassword'] = 'Inserir a senha, por favor';
$string['eolstudentoutoftime'] = 'Ateno: O tempo para terminar esta lio acabou. Se a sua litma resposta foi enviada quando o tempo de durao j tinha sido superado, ela no ser considerada.';
$string['eolstudentoutoftimenoanswers'] = 'Voc no respondeu nenhuma questo. A nota atribuda foi igual a 0 .';
$string['essay'] = 'Dissertao';
$string['essayemailsubject'] = 'A sua nota da questo $a';
$string['essays'] = 'Dissertaes';
$string['essayscore'] = 'Nota da dissertao';
$string['fileformat'] = 'Formato do documento';
$string['firstanswershould'] = 'A primeira resposta deve ter como destinao a pgina  correta';
$string['firstwrong'] = 'Infelizmente esta resposta no  correta e portanto no aumentar a sua pontuao. Voc gostaria de continuar tentando para conhecer a resposta certa (mas sem direito  reviso da pontuao)?';
$string['flowcontrol'] = 'Controle de fluxo';
$string['general'] = 'Geral';
$string['gobacktolesson'] = 'Retornar  Lio';
$string['grade'] = 'Avaliao';
$string['gradebetterthan'] = 'Avaliao melhor que (%%)';
$string['gradebetterthanerror'] = 'Tem nota superior a $a por cento';
$string['gradeessay'] = 'Avaliar dissertaes';
$string['gradeis'] = 'Resultado: $a';
$string['gradeoptions'] = 'Opes de avaliao';
$string['handlingofretakes'] = 'Clculo do resultado das tentativas';
$string['havenotgradedyet'] = 'Ainda no foi avaliado';
$string['here'] = 'aqui';
$string['highscore'] = 'Pontuao alta';
$string['hightime'] = 'Tempo alto';
$string['importppt'] = 'Importar PowerPoint';
$string['importquestions'] = 'Importar questes';
$string['insertedpage'] = 'Inserir pgina';
$string['jump'] = 'Destinao';
$string['jumptsto'] = 'ir para';
$string['leftduringtimed'] = 'Voc interrompeu uma lio com tempo de durao definido.<br />Por favor clique em Continuar para recomear a lio.';
$string['leftduringtimednoretake'] = 'Voc interrompeu uma lio com tempo de durao definido.<br />No ser possvel continuar ou recomear.';
$string['lesson'] = '$a Lio';
$string['lessonclosed'] = 'Esta lio foi fechada em $a.';
$string['lessoncloses'] = 'A lio termina';
$string['lessondefault'] = 'Usar as configuraes desta lio como padro';
$string['lessonformating'] = 'Formatao da lio';
$string['lessonmenu'] = 'Menu da lio';
$string['lessonopen'] = 'Esta lio ser acessvel a partir de $a.';
$string['lessonopens'] = 'A lio inicia';
$string['lessonstats'] = 'Estatsticas da Lio';
$string['loginfail'] = 'Erro de login, por favor tente novamente';
$string['lowscore'] = 'Pontuao baixa';
$string['lowtime'] = 'Tempo breve';
$string['mainmenu'] = 'Menu principal';
$string['matchesanswer'] = 'Corresponde  resposta';
$string['maxhighscores'] = 'Nmero de pontuaes altas visualizado';
$string['maximumnumberofanswersbranches'] = 'Nmero mximo de respostas/sees';
$string['maximumnumberofattempts'] = 'Nmero mximo de tentativas';
$string['maxtime'] = 'Limite temporal (minutos)';
$string['maxtimewarning'] = 'Voc tem $a minuto(s) para terminar esta lio.';
$string['mediafile'] = 'Arquivo multimedial';
$string['mediafilepopup'] = 'Clique aqui para ver o arquivo multimedial desta lio';
$string['minimumnumberofquestions'] = 'Nmero mnimo  de questes';
$string['modattempts'] = 'Permitir reviso pelo estudante';
$string['modattemptsnoteacher'] = 'A reviso dos estudantes s  ativa para eles.';
$string['modulename'] = 'Lio';
$string['modulenameplural'] = 'Lies';
$string['movedpage'] = 'Pgina transferida';
$string['movepagehere'] = 'Mover pgina para c';
$string['moving'] = 'Movendo pgina: $a';
$string['movingtonextpage'] = 'Movendo para a prxima pgina';
$string['multianswer'] = 'Multianswer';
$string['multipleanswer'] = 'Resposta mltipla';
$string['nameapproved'] = 'Nome aprovado';
$string['namereject'] = 'Sinto muito, o seu nome no foi aceito pelo filtro.<br />Por favor use um outro nome.';
$string['nextpage'] = 'Prxima pgina';
$string['noanswer'] = 'No foi dada nenhuma resposta';
$string['noattemptrecordsfound'] = 'No foram encontrados registros de tentativas para esta lio: no foi definido nenhum resultado';
$string['nocommentyet'] = 'Ainda nenhum comentrio';
$string['nohighscores'] = 'Nenhuma pontuao alta';
$string['nooneansweredcorrectly'] = 'Ningum respondeu corretamente.';
$string['nooneansweredthisquestion'] = 'Ningum respondeu esta questo';
$string['noonecheckedthis'] = 'Ningum controlou isto.';
$string['nooneenteredthis'] = 'Ningum inseriu isto.';
$string['noretake'] = 'No  permitido refazer esta lio';
$string['normal'] = 'Normal - seguir percurso da lio';
$string['notcompleted'] = 'No completado';
$string['notdefined'] = 'No definido';
$string['nothighscore'] = 'O seu resultado no est includo entre os melhores $a da lista.';
$string['notitle'] = 'Nenhum ttulo';
$string['numberofcorrectanswers'] = 'Nmero de respostas corretas: $a';
$string['numberofcorrectmatches'] = 'Nmero de associaes corretas';
$string['numberofpagestoshow'] = 'Nmero  de pginas (fichas) a serem mostradas ';
$string['numberofpagesviewed'] = 'Nmero de pginas vistas: $a';
$string['ongoing'] = 'Visualizar pontuao corrente';
$string['ongoingcustom'] = 'Esta lio corresponde a $a->grade pontos. Voc recebeu $a->score ponto(s) de um total de $a->currenthigh pontos at agora.';
$string['ongoingnormal'] = 'Voc respondeu corretamente $a->correct questes de um total de $a->viewed .';
$string['or'] = 'OU';
$string['ordered'] = 'Ordenada';
$string['other'] = 'Outro';
$string['outof'] = 'de $a';
$string['outoftime'] = 'Sem tempo';
$string['overview'] = 'Viso geral';
$string['page'] = 'Pgina: $a';
$string['pagecontents'] = 'Contedo da pgina';
$string['pages'] = 'Pginas';
$string['pagetitle'] = 'Ttulo da pgina';
$string['password'] = 'Senha';
$string['passwordprotectedlesson'] = '$a  uma atividade protegida por uma senha';
$string['pleasecheckoneanswer'] = 'Salvar a resposta selecionada';
$string['pleasecheckoneormoreanswers'] = 'Salvar as respostas selecionadas';
$string['pleaseenteryouranswerinthebox'] = 'Salvar a resposta escrita no box ';
$string['pleasematchtheabovepairs'] = 'Salvar os pares associados acima';
$string['pointsearned'] = 'Pontos recebidos';
$string['postsuccess'] = 'Envio bem sucedido';
$string['practice'] = 'Exerccio';
$string['previouspage'] = 'Pgina anterior';
$string['question'] = 'Questo';
$string['questionoption'] = 'Modalidade opcional';
$string['questiontype'] = 'Tipo de questo';
$string['randombranch'] = 'Pgina de seo aleatria';
$string['randompageinbranch'] = 'Questo aleatria de uma seo';
$string['rank'] = 'Classificao';
$string['reached'] = 'alcanado';
$string['receivedcredit'] = 'Creditos recebidos';
$string['redisplaypage'] = 'Mostrar pgina de novo';
$string['report'] = 'Relatrio';
$string['response'] = 'Comentrio';
$string['returnmainmenu'] = 'Voltar ao men';
$string['returntocourse'] = 'Voltar ao curso';
$string['reviewlesson'] = 'Rever Lio';
$string['reviewquestionback'] = 'Sim, eu gostaria de tentar novamente';
$string['reviewquestioncontinue'] = 'No, quero continuar com a prxima questo';
$string['sanitycheckfailed'] = 'O controle dos dados falhou: Esta tentativa foi cancelada';
$string['savechanges'] = 'Salvar mudanas';
$string['savechangesandeol'] = 'Salvar todas as mudanas e ir para o fim da lio';
$string['savepage'] = 'Salvar pgina';
$string['score'] = 'Pontuao';
$string['scores'] = 'Pontuaes';
$string['secondpluswrong'] = 'No  exato. Voc quer tentar novamente?';
$string['showanunansweredpage'] = 'Mostrar uma pgina que ainda no foi respondida';
$string['showanunseenpage'] = 'Mostrar uma pgina que ainda no foi visitada';
$string['singleanswer'] = 'Resposta nica';
$string['slideshow'] = 'Apresentao de Slides';
$string['slideshowbgcolor'] = 'Cr do fundo da pgina da Apresentao de Slides';
$string['slideshowheight'] = 'Altura da Apresentao de Slides';
$string['slideshowwidth'] = 'Largura da Apresentao de Slides';
$string['startlesson'] = 'Iniciar Lio';
$string['studentattemptlesson'] = 'nmero da tentativa $a->attempt de $a->lastname, $a->firstname';
$string['studentname'] = '$a Nome';
$string['studentoneminwarning'] = 'Ateno: Voc tem menos de 1 minuto para acabar a lio.';
$string['studentoutoftime'] = 'Ateno: acabou o tempo de durao desta lio. A sua ltima resposta no ser considerada porque foi enviada depois do termo. Por favor clique o boto Continuar para encerrar esta lio';
$string['studentresponse'] = 'resposta de {$a}';
$string['submitname'] = 'Enviar nome';
$string['teacherjumpwarning'] = 'Uma destinao $a->cluster ou uma destinao $a->unseen est sendo usado nesta lio. A destinao Prxima Pgina substituir a anterior. Faa o login como estudante para testar estas destinaes.';
$string['teacherongoingwarning'] = 'Para testar a pontuao corrente  necessrio fazer o login como estudante.';
$string['teachertimerwarning'] = 'Para testar o timer  necessrio fazer o login como estudante.';
$string['thatsthecorrectanswer'] = 'Esta  a resposta correta';
$string['thatsthewronganswer'] = 'Esta  a resposta errada';
$string['thefollowingpagesjumptothispage'] = 'As seguintes pginas tem como destinao esta pgina';
$string['thispage'] = 'Esta pgina';
$string['timed'] = 'Tempo determinado';
$string['timeremaining'] = 'Tempo restante';
$string['timespenterror'] = 'Dedica pelo menos $a  a esta lio';
$string['timespentminutes'] = 'Tempo dedicado (em minutos)';
$string['timetaken'] = 'Tempo utilizado';
$string['topscorestitle'] = '$a->maxhighscores melhores pontuaes da lio $a->name .';
$string['treeview'] = 'Vista em forma de ramos';
$string['unseenpageinbranch'] = 'Questo no vista de uma seo';
$string['updatedpage'] = 'Pgina atualizada';
$string['updatefailed'] = 'Erro na atualizao';
$string['updatesuccess'] = 'Atualizao bem sucedida';
$string['useeditor'] = 'Usar editor';
$string['usemaximum'] = 'Usar melhor resultado entre as tentativas';
$string['usemean'] = 'Usar mdia das tentativas';
$string['usepassword'] = 'Lio protegida por senha';
$string['viewallpages'] = 'Ver todas as pginas';
$string['viewgrades'] = 'Ver notas';
$string['viewhighscores'] = 'Ver lista dos melhores resultados';
$string['viewlessonstats'] = 'Ver estatsticas da lio';
$string['waitpostscore'] = 'Por favor espere enquanto a pontuao est sendo enviada...';
$string['welldone'] = 'Muito bem!';
$string['whatdofirst'] = 'O que voc gostaria de fazer primeiro?';
$string['wronganswerjump'] = 'Destinao da resposta errada';
$string['wronganswerscore'] = 'Pontuao da resposta errada';
$string['wrongresponse'] = 'Resposta errada';
$string['youhavereceived'] = 'Voc recebeu $a->score sobre $a->outof pontos nesta questo dissertativa';
$string['youhaveseen'] = 'Voc j visitou algumas pginas desta lio.<br />Voc quer iniciar a partir da ltima pgina visitada?';
$string['youmadehighscore'] = 'O seu resultado est incluido entre os melhores $a .';
$string['youranswer'] = 'A sua resposta';
$string['yourcurrentgradeis'] = 'A sua avaliao atual  $a';
$string['yourgradeisnow'] = 'A sua nota foi modificada para $a';
$string['yourresponse'] = 'A sua resposta';
$string['youshouldview'] = 'Voc deve visitar pelo menos: $a';

?>
